@@ -105,8 +105,8 @@ class MarionetteTestExecutor(TestExecutor):
             try:
                 self.after_connect()
             except Exception as e:
-                print >> sys.stderr, traceback.format_exc()
-                self.logger.warning("Failed to connect to navigate initial page")
+                self.logger.warning("Post-connection steps failed")
+                self.logger.error(traceback.format_exc())
                 self.runner.send_message("init_failed")
             else:
                 self.runner.send_message("init_succeeded")
@@ -186,7 +186,7 @@ class MarionetteTestExecutor(TestExecutor):
             #     else:
             #         break
             # Now need to check if the browser is still responsive and restart it if not
-        except (socket.timeout, marionette.errors.InvalidResponseException) as e:
+        except (socket.timeout, marionette.errors.InvalidResponseException, IOError) as e:
             # This can happen on a crash
             # Also, should check after the test if the firefox process is still running
             # and otherwise ignore any other result and set it to crash
@@ -220,11 +220,7 @@ class MarionetteTestharnessExecutor(MarionetteTestExecutor):
 
 class B2GMarionetteTestharnessExecutor(MarionetteTestharnessExecutor):
     def after_connect(self):
-        try:
-            self.browser.after_connect(self)
-        except Exception as e:
-            print e
-            sys.exit(1)
+        self.browser.after_connect(self)
         MarionetteTestharnessExecutor.after_connect(self)
 
 
