@@ -337,7 +337,10 @@ class LogThread(threading.Thread):
 
     def run(self):
         while True:
-            msg = self.queue.get()
+            try:
+                msg = self.queue.get()
+            except EOFError:
+                break
             if msg is None:
                 break
             else:
